Eurocode 1-1-2
===================

BS EN 1991-1-2:2002 - General Actions: Actions on structures exposed to fire.

BS EN 1991-1-2 provides general rules for the determination of thermal actions on structures exposed to fire and their application for structural analysis. The standard specifies:

- Temperature-time curves for standard fire exposure (including the standard temperature-time curve)
- Natural fire models for compartment fires
- Thermal material properties for structural materials at elevated temperatures  
- Methods for determining temperature distributions in structural members
- Thermal actions for structural fire design

.. automodule:: ofire.eurocode_1_1_2
   :members:
   :undoc-members:
   :show-inheritance:

Section 3 - Thermal actions for temperature analysis
------------------------------------------

.. automodule:: ofire.eurocode_1_1_2.section_3
   :members:
   :undoc-members:
   :show-inheritance:

Equation Modules
~~~~~~~~~~~~~~~~

Equation 3.1 - Net Heat Flux 
"""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.eurocode_1_1_2.section_3.equation_3_1
   :members:
   :undoc-members:
   :show-inheritance:

Equation 3.2 - Net convective heat flux
"""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.eurocode_1_1_2.section_3.equation_3_2
   :members:
   :undoc-members:
   :show-inheritance:

Equation 3.3 - Net radiative heat flux
""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.eurocode_1_1_2.section_3.equation_3_3
   :members:
   :undoc-members:
   :show-inheritance:

Equation 3.4 - Standard temperature-time curve
"""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.eurocode_1_1_2.section_3.equation_3_4
   :members:
   :undoc-members:
   :show-inheritance:

Equation 3.5 - External fire curve
""""""""""""""""""""""""""""""""""

.. automodule:: ofire.eurocode_1_1_2.section_3.equation_3_5
   :members:
   :undoc-members:
   :show-inheritance:

Equation 3.6 - Hydrocarbon temperature-time curve
"""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.eurocode_1_1_2.section_3.equation_3_6
   :members:
   :undoc-members:
   :show-inheritance: